import {
  select,
  symbolCircle,
  symbolSquare,
  symbolTriangle
} from 'd3';
import { colorsPanel } from './colorsPanel';
import { sizePanel } from './sizePanel';
import { shapePanel } from './shapePanel';
import { mark } from './mark';

const svg = select('svg');

const colors = [
  '#c11d1d',
  '#eae600',
  'green',
  'orange'
];
const sizes = [20, 30, 45, 60];
const shapes = [
  symbolCircle,
  symbolSquare,
  symbolTriangle
];

// State
let color = 'grey';
let size = sizes[3];
let shape = symbolCircle;

const onColorClick = clickedColor => {
  color = clickedColor;
  render();
};

const onSizeClick = clickedSize => {
  size = clickedSize;
  render();
};

const onShapeClick = clickedShape => {
  shape = clickedShape;
  render();
};

const colorsG = svg.append('g')
    .attr('transform', `translate(120,600)`);

const sizeG = svg.append('g')
    .attr('transform', `translate(529,600)`);

const shapesG = svg.append('g')
    .attr('transform', `translate(115,118)`);

const markG = svg.append('g')
    .attr('transform', `translate(556,259)`);

const render = () => {
  const width = document.body.clientWidth;
  const height = document.body.clientHeight;

  svg
      .attr('width', width)
      .attr('height', height);
  
  markG.call(mark, {
    color,
    size,
    shape
  });
  
  colorsG.call(colorsPanel, {
    colors,
    circleRadius: 40,
    spacing: 90,
    onCircleClick: onColorClick
  });
  
  sizeG.call(sizePanel, {
    sizes,
    spacing: 15,
    onCircleClick: onSizeClick
  });
  
  shapesG.call(shapePanel, {
    shapes,
    spacing: 155,
    onClick: onShapeClick
  });
};

render();